<?php
/*
Plugin Name: Hide Theme Update Notices
Description: A plugin to hide all theme update-related notices in WordPress.
Version: 1.0
Author: Idee by <a href="https://mbsm.tn" target="_blank">Mbsmgroup</a>, Programmed by <a href="https://deepseek.com" target="_blank">Deepseek</a>
Plugin URI: #
*/

// Security check: Prevent direct access to the file
if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly
}

// Hide all theme update notices
function tuc_hide_all_theme_update_notices() {
    // Check user capabilities to ensure only admins can modify settings
    if (!current_user_can('manage_options')) {
        return;
    }

    // Hide theme update notices from the dashboard
    remove_action('admin_notices', 'update_nag', 3);

    // Hide theme update notices from the updates page
    remove_action('core_upgrade_preamble', 'core_update_nag', 10);

    // Hide theme update notices from the themes page
    remove_action('load-themes.php', 'wp_update_themes');
    remove_action('load-update-core.php', 'wp_update_themes');
    remove_action('admin_init', '_maybe_update_themes');
    remove_action('wp_update_themes', 'wp_update_themes');

    // Hide theme updates from the updates list
    add_filter('pre_site_transient_update_themes', '__return_null');
}
add_action('admin_init', 'tuc_hide_all_theme_update_notices', 1);

// Hide theme update notices from the toolbar
function tuc_hide_theme_update_toolbar_notices($wp_admin_bar) {
    // Check user capabilities to ensure only admins can modify settings
    if (!current_user_can('manage_options')) {
        return;
    }

    $wp_admin_bar->remove_node('updates');
}
add_action('admin_bar_menu', 'tuc_hide_theme_update_toolbar_notices', 999);

// Hide theme updates from the updates page (Update Core)
function tuc_hide_theme_updates_from_core_page() {
    // Check user capabilities to ensure only admins can modify settings
    if (!current_user_can('manage_options')) {
        return;
    }

    global $wp_filter;

    // Hide theme updates from the updates page
    if (isset($wp_filter['site_transient_update_themes'])) {
        unset($wp_filter['site_transient_update_themes']);
    }
}
add_action('admin_init', 'tuc_hide_theme_updates_from_core_page', 1);

// Add a contact link in the plugin description
function tuc_add_plugin_meta_links($links, $file) {
    // Check if the current plugin is being filtered
    if (plugin_basename(__FILE__) === $file) {
        // Add a "Contact Us" link
        $links[] = '<a href="mailto:mbsmgroup@gmail.com">Contact Us</a>';
    }
    return $links;
}
add_filter('plugin_row_meta', 'tuc_add_plugin_meta_links', 10, 2);